@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 from django.shortcuts import render_to_response
 #from django.template.context import RequestContext
 import random
@@ -47,10 +48,31 @@ def demo_linechart(request):
     chartdata = {'x': xdata,
                  'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie,
                  'name2': 'series 2', 'y2': ydata2, 'extra2': extra_serie}
+
     charttype = "lineChart"
     data = {
         'charttype': charttype,
-        'chartdata': chartdata
+        'chartdata': chartdata,
+        'date_tag' : True,
+    }
+    return render_to_response('linechart.html', data)
+
+
+def demo_linechart_without_date(request):
+    """
+    lineChart page
+    """
+    extra_serie = {}
+    xdata = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12]
+    ydata = [3, 5, 7, 8, 3, 5, 3, 5, 7, 6, 3, 1]
+    chartdata = {'x': xdata,
+                 'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie,
+                }
+    charttype = "lineChart"
+    data = {
+        'charttype': charttype,
+        'chartdata': chartdata,
+        'date_tag' : False,
     }
     return render_to_response('linechart.html', data)
 
@@ -297,3 +319,30 @@ def demo_scatterchart(request):
         'chartdata': chartdata,
     }
     return render_to_response('scatterchart.html', data)
+
+
+def demo_linechart_with_ampm(request):
+    """
+    lineChart page
+    """
+    xdata = []
+    ydata = []
+    ydata2 = []
+
+    ydata = [0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 0, 4, 3, 3, 5, 7, 5, 3, 16, 6, 9, 15, 4, 12]
+    ydata2 = [9, 8, 11, 8, 3, 7, 10, 8, 6, 6, 9, 6, 5, 4, 3, 10, 0, 6, 3, 1, 0, 0, 0, 1]
+
+    for i in range(0, 24):
+        xdata.append(i)
+
+    tooltip_date = ""#"%d %b %Y %H:%M:%S %p"
+    extra_serie = {"tooltip": {"y_start": "", "y_end": " cal"}}
+    chartdata = {'x': xdata,
+                 'name1': 'series 1', 'y1': ydata, 'extra1': extra_serie,
+                 'name2': 'series 2', 'y2': ydata2, 'extra2': extra_serie}
+    charttype = "lineChart"
+    data = {
+        'charttype': charttype,
+        'chartdata': chartdata
+    }
+    return render_to_response('linechart_with_ampm.html', data)
\ No newline at end of file
